Hyw

Struct Hyw 

pub struct Hyw { /* private fields */ }
A combination of these characters.

Implementations

Source

impl Hyw

pub const fn new() -> Self

Create a new Hyw.

pub const fn from_index(index: usize) -> Option<Self>

Create a Hyw from combined index. If the index is out of bounds, return None.

pub const fn to_index(&self) -> usize

Get the combined index of this Hyw.

pub const fn next(&self) -> Option<Self>

Get the next Hyw combination. If it is the last combination, return None.

pub const fn previous(&self) -> Option<Self>

Get the previous Hyw combination. If it is the first combination, return None.

pub const fn iter_from(self) -> HywIterator

Returns an iterator over all Hyw combinations starting from this one

pub const fn all() -> HywIterator

Returns an iterator over all possible Hyw combinations

pub const fn set_he(&mut self, he: usize) -> bool

Set the indice of character with pinyin “he”. If the index is out of bounds, return false and do not modify the value.

pub const fn set_yi(&mut self, yi: usize) -> bool

Set the indice of character with pinyin “yi”. If the index is out of bounds, return false and do not modify the value.

pub const fn set_wei(&mut self, wei: usize) -> bool

Set the indice of character with pinyin “wei”. If the index is out of bounds, return false and do not modify the value.